# from pydantic import BaseModel
#
#
#
#
# class SearchSelect(BaseModel):
#     type: str = 'search_select'
#     placeholder: str | None
#     multiselect: bool = False
#     # trigger_on_input: bool
#     value: list[str] | None
#     options: list[Option] = []
